@@ -109,14 +109,13 @@ class CameraModelAdmin(SimpleHistoryAdmin):
             'fields': ('focus_type', 'af_points', 'dof_preview')
         }),
         ('Shutter', {
-            'fields': ('shutter_type', 'shutter_model', 'shutter_speeds', 'bulb', 'time'),
+            'fields': ('shutter_type', 'shutter_model', 'fastest_shutter_speed', 'slowest_shutter_speed', 'bulb', 'time'),
         }),
     )
     inlines = [
         CameraInline,
     ]
-    filter_horizontal = (
-        'metering_modes', 'exposure_programs', 'shutter_speeds')
+    filter_horizontal = ('metering_modes', 'exposure_programs')
     search_fields = ['manufacturer__name', 'model', 'notes']
     list_display = ('__str__', 'mount', 'format', 'body_type', 'introduced')
     list_filter = ('manufacturer__name', 'mount', 'format', 'body_type')
@@ -174,7 +173,7 @@ class LensModelAdmin(SimpleHistoryAdmin):
             'fields': ('length', 'diameter', 'weight'),
         }),
         ('Other', {
-            'fields': ('aperture_blades', 'autofocus', 'filter_thread', 'url', 'introduced', 'discontinued', 'negative_size', 'notes', 'coating', 'hood', 'rectilinear', 'image_circle', 'shutter_model'),
+            'fields': ('aperture_blades', 'autofocus', 'filter_thread', 'url', 'introduced', 'discontinued', 'negative_size', 'notes', 'coating', 'hood', 'image_circle', 'shutter_model'),
         })
     )
     inlines = [
